@@ -2,7 +2,7 @@ package Pod::WikiDoc;
 use strict;
 use warnings;
 use vars qw($VERSION );
-$VERSION     = "0.11";
+$VERSION     = "0.12";
 
 use 5.006;
 use Carp;
@@ -89,7 +89,8 @@ Pod escape equivalents, e.g. \E\<lt\>, \E\<gt\>
 In addition, Pod::WikiDoc provides a command-line utility, [wikidoc],
 to simplify wikidoc translation.
 
-See the [Pod::WikiDoc::Cookbook] for more detailed usage examples.
+See the [Pod::WikiDoc::Cookbook] for more detailed usage examples, 
+including how to automate {.pod} generation when using [Module::Build].
 
 = INTERFACE
 
@@ -234,7 +235,11 @@ sub filter {
 ###     my $pod_text = $parser->format( $wiki_text );
 ### 
 ### Given a string with valid Pod and/or wikidoc markup, filter/translate it to
-### Pod. Unlike {convert}, no 'Generated by' comment is added.
+### Pod. Unlike {convert}, no 'Generated by' comment is added.  This 
+### function is used internally by Pod::WikiDoc, but is being made available
+### as a public method for users who want more granular control of the 
+### translation process or who want to convert wikidoc to Pod for other
+### creative purposes using the Pod::WikiDoc engine.
 
 sub format {
     my ($self, $wikitext) = @_;
@@ -559,17 +564,20 @@ Block elements include:
 * Numbered lists
 * Ordinary paragraphs
 
+Block elements should be separated by a blank line (though Pod::WikiDoc 
+will do the right thing in many cases if you don't).
+
 Inline elements include:
-* Bold markup
-* Italic markup
-* Code markup
-* Link markup
-* Escape code markup
+* Bold
+* Italic
+* Code
+* Link
+* Escape code
 
 All text except that found in verbatim text or code markup is transformed to
-convert Pod special elements to Pod escape code markup: \E\<lt\>, \E\<gt\>,
-\E\<sol\>, \E\<verbar\>.  Inline markup can be escaped with a backslash.
-Including a literal backslash requires a double-backslash.
+convert special Pod characters to Pod escape code markup: \E\<lt\>, \E\<gt\>,
+\E\<sol\>, \E\<verbar\>.  Inline markup can be escaped with a backslash (\\).
+Including a literal backslash requires a double-backslash (\\\\).
 
 == Headers
 
@@ -677,11 +685,12 @@ or other unusual characters.
 = DEPENDENCIES
 
 Pod::WikiDoc and the 'wikidoc' script depend on the following modules:
-* [Getopt::Std]
+* [Getopt::Long]
 * [IO::String]
 * [Parse::RecDescent]
 * [Pod::Usage]
 * [Scalar::Util]
+* [Text::Balanced]
 
 = INCOMPATIBILITIES
 
